@@ -2,19 +2,20 @@
 /*
  *  Copyright (C) 2003 Johan Dahlin
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ *  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1171,8 +1172,10 @@ do_file_control (GnomeVFSMethod       *method,
 GnomeVFSMethod *
 vfs_module_init (const char *method_name, const char *args)
 {
-	PyObject *instance, *class_object, *d, *m, *path;
+	PyObject *instance, *class_object, *d, *m;
+	PyObject *path, *py_vfs_dir, *py_home_dir;
 	char *full_name;
+	char *home_dir;
 	PyVFSMethod *pymethod;
 	PyGILState_STATE state = 0;
 	
@@ -1196,8 +1199,19 @@ vfs_module_init (const char *method_name, const char *args)
 	PyEval_InitThreads();
 	init_pygnomevfs();
 
+	py_vfs_dir = PyString_FromString(GNOME_VFS_PYTHON_DIR);
+
+	home_dir = g_strdup_printf("%s/.gnome2/vfs/pythonmethod",
+				   g_get_home_dir());
+	py_home_dir = PyString_FromString(home_dir);
+	g_free(home_dir);
+
 	path = PySys_GetObject("path");
-	PyList_Insert(path, 0, PyString_FromString(GNOME_VFS_PYTHON_DIR));
+	PyList_Insert(path, 0, py_vfs_dir);
+	PyList_Insert(path, 0, py_home_dir);
+
+	Py_DECREF(py_vfs_dir);
+	Py_DECREF(py_home_dir);
 
 	m = PyImport_ImportModule(g_strdup(method_name));
 	if (!m) {
